/**
 * @copyright nhcarrigan
 * @license Naomi's Public License
 * @author Naomi Carrigan
 */

import type { onRequestHookHandler } from "fastify";

/**
 * Ensures that form submissions only come from our web application.
 * @param request - The request payload from the server.
 * @param response - The reply handler from Fastify.
 * @returns A Fastify reply if the request is invalid, otherwise undefined.
 */
// eslint-disable-next-line @typescript-eslint/no-misused-promises -- For reasons I cannot comprehend, Fastify seems to require us to return a request?
export const corsHook: onRequestHookHandler = async(request, response) => {
  if (!request.url.startsWith("/submit")) {
    return undefined;
  }
  if (request.headers.origin !== "http://localhost:4200"
      && request.headers.origin !== "https://hikari.nhcarrigan.com") {
    console.log(request);
    return await response.
      status(403).
      send({
        error: "This route is only accessible from our dashboard at https://hikari.nhcarrigan.com.",
      });
  }
  return undefined;
};
